# Generated by roxygen2: do not edit by hand

S3method("!=",xlr_format)
S3method("==",xlr_format)
S3method(arrange,xlr_table)
S3method(as.character,xlr_n_percent)
S3method(as.character,xlr_numeric)
S3method(as.character,xlr_percent)
S3method(as.numeric,xlr_numeric)
S3method(as_base_r,default)
S3method(as_base_r,xlr_table)
S3method(as_xlr_integer,character)
S3method(as_xlr_integer,default)
S3method(as_xlr_numeric,character)
S3method(as_xlr_numeric,default)
S3method(as_xlr_percent,character)
S3method(as_xlr_percent,default)
S3method(as_xlr_table,data.frame)
S3method(as_xlr_table,default)
S3method(as_xlr_vector,default)
S3method(distinct,xlr_table)
S3method(filter,xlr_table)
S3method(format,xlr_integer)
S3method(format,xlr_n_percent)
S3method(format,xlr_numeric)
S3method(format,xlr_percent)
S3method(format,xlr_vector)
S3method(median,xlr_integer)
S3method(median,xlr_numeric)
S3method(median,xlr_percent)
S3method(mutate,xlr_table)
S3method(pillar_shaft,xlr_vector)
S3method(pivot_longer,xlr_table)
S3method(pivot_wider,xlr_table)
S3method(print,xlr_format)
S3method(quantile,xlr_integer)
S3method(quantile,xlr_numeric)
S3method(quantile,xlr_percent)
S3method(relocate,xlr_table)
S3method(rename,xlr_table)
S3method(rename_with,xlr_table)
S3method(rowwise,xlr_table)
S3method(select,xlr_table)
S3method(slice,xlr_table)
S3method(slice_head,xlr_table)
S3method(slice_max,xlr_table)
S3method(slice_min,xlr_table)
S3method(slice_sample,xlr_table)
S3method(slice_tail,xlr_table)
S3method(summarise,xlr_table)
S3method(summarize,xlr_table)
S3method(tbl_format_footer,xlr_table)
S3method(tbl_sum,xlr_table)
S3method(vec_arith,xlr_integer)
S3method(vec_arith,xlr_n_percent)
S3method(vec_arith,xlr_numeric)
S3method(vec_arith,xlr_percent)
S3method(vec_arith.numeric,xlr_integer)
S3method(vec_arith.numeric,xlr_numeric)
S3method(vec_arith.numeric,xlr_percent)
S3method(vec_arith.xlr_integer,default)
S3method(vec_arith.xlr_integer,numeric)
S3method(vec_arith.xlr_integer,xlr_integer)
S3method(vec_arith.xlr_n_percent,default)
S3method(vec_arith.xlr_n_percent,xlr_n_percent)
S3method(vec_arith.xlr_numeric,default)
S3method(vec_arith.xlr_numeric,numeric)
S3method(vec_arith.xlr_numeric,xlr_numeric)
S3method(vec_arith.xlr_percent,default)
S3method(vec_arith.xlr_percent,numeric)
S3method(vec_arith.xlr_percent,xlr_percent)
S3method(vec_cast,character.xlr_n_percent)
S3method(vec_cast,character.xlr_percent)
S3method(vec_cast,character.xlr_vector)
S3method(vec_cast,complex.xlr_vector)
S3method(vec_cast,double.xlr_integer)
S3method(vec_cast,double.xlr_numeric)
S3method(vec_cast,double.xlr_percent)
S3method(vec_cast,double.xlr_vector)
S3method(vec_cast,integer.xlr_integer)
S3method(vec_cast,integer.xlr_numeric)
S3method(vec_cast,integer.xlr_percent)
S3method(vec_cast,integer.xlr_vector)
S3method(vec_cast,numeric.xlr_numeric)
S3method(vec_cast,numeric.xlr_percent)
S3method(vec_cast,numeric.xlr_vector)
S3method(vec_cast,xlr_integer.double)
S3method(vec_cast,xlr_integer.integer)
S3method(vec_cast,xlr_integer.xlr_integer)
S3method(vec_cast,xlr_integer.xlr_numeric)
S3method(vec_cast,xlr_integer.xlr_percent)
S3method(vec_cast,xlr_n_percent.xlr_n_percent)
S3method(vec_cast,xlr_numeric.double)
S3method(vec_cast,xlr_numeric.integer)
S3method(vec_cast,xlr_numeric.numeric)
S3method(vec_cast,xlr_numeric.xlr_integer)
S3method(vec_cast,xlr_numeric.xlr_numeric)
S3method(vec_cast,xlr_numeric.xlr_percent)
S3method(vec_cast,xlr_percent.character)
S3method(vec_cast,xlr_percent.double)
S3method(vec_cast,xlr_percent.integer)
S3method(vec_cast,xlr_percent.numeric)
S3method(vec_cast,xlr_percent.xlr_numeric)
S3method(vec_cast,xlr_percent.xlr_percent)
S3method(vec_cast,xlr_vector.xlr_vector)
S3method(vec_math,xlr_integer)
S3method(vec_math,xlr_n_percent)
S3method(vec_math,xlr_numeric)
S3method(vec_math,xlr_percent)
S3method(vec_ptype2,character.xlr_percent)
S3method(vec_ptype2,character.xlr_vector)
S3method(vec_ptype2,complex.xlr_vector)
S3method(vec_ptype2,double.xlr_integer)
S3method(vec_ptype2,double.xlr_numeric)
S3method(vec_ptype2,double.xlr_percent)
S3method(vec_ptype2,double.xlr_vector)
S3method(vec_ptype2,integer.xlr_integer)
S3method(vec_ptype2,integer.xlr_numeric)
S3method(vec_ptype2,integer.xlr_percent)
S3method(vec_ptype2,integer.xlr_vector)
S3method(vec_ptype2,numeric.xlr_numeric)
S3method(vec_ptype2,numeric.xlr_percent)
S3method(vec_ptype2,numeric.xlr_vector)
S3method(vec_ptype2,xlr_integer.double)
S3method(vec_ptype2,xlr_integer.integer)
S3method(vec_ptype2,xlr_integer.xlr_integer)
S3method(vec_ptype2,xlr_integer.xlr_numeric)
S3method(vec_ptype2,xlr_integer.xlr_percent)
S3method(vec_ptype2,xlr_n_percent.xlr_n_percent)
S3method(vec_ptype2,xlr_numeric.double)
S3method(vec_ptype2,xlr_numeric.integer)
S3method(vec_ptype2,xlr_numeric.numeric)
S3method(vec_ptype2,xlr_numeric.xlr_integer)
S3method(vec_ptype2,xlr_numeric.xlr_numeric)
S3method(vec_ptype2,xlr_numeric.xlr_percent)
S3method(vec_ptype2,xlr_percent.character)
S3method(vec_ptype2,xlr_percent.double)
S3method(vec_ptype2,xlr_percent.integer)
S3method(vec_ptype2,xlr_percent.numeric)
S3method(vec_ptype2,xlr_percent.xlr_numeric)
S3method(vec_ptype2,xlr_percent.xlr_percent)
S3method(vec_ptype2,xlr_vector.character)
S3method(vec_ptype2,xlr_vector.complex)
S3method(vec_ptype2,xlr_vector.double)
S3method(vec_ptype2,xlr_vector.integer)
S3method(vec_ptype2,xlr_vector.numeric)
S3method(vec_ptype2,xlr_vector.xlr_vector)
S3method(vec_ptype_abbr,xlr_integer)
S3method(vec_ptype_abbr,xlr_n_percent)
S3method(vec_ptype_abbr,xlr_numeric)
S3method(vec_ptype_abbr,xlr_percent)
S3method(vec_ptype_abbr,xlr_vector)
export(as_base_r)
export(as_xlr_integer)
export(as_xlr_numeric)
export(as_xlr_percent)
export(as_xlr_table)
export(as_xlr_vector)
export(build_mtable)
export(build_qtable)
export(build_table)
export(create_table_of_contents)
export(is_xlr_format)
export(is_xlr_integer)
export(is_xlr_n_percent)
export(is_xlr_numeric)
export(is_xlr_percent)
export(is_xlr_table)
export(is_xlr_type)
export(is_xlr_vector)
export(make_wider)
export(update_theme)
export(write_xlsx)
export(xlr_format)
export(xlr_format_numeric)
export(xlr_integer)
export(xlr_n_percent)
export(xlr_numeric)
export(xlr_percent)
export(xlr_table)
export(xlr_vector)
import(openxlsx)
import(rlang)
import(vctrs)
importFrom(cli,cli_abort)
importFrom(cli,cli_alert)
importFrom(cli,cli_alert_info)
importFrom(cli,cli_fmt)
importFrom(cli,cli_h1)
importFrom(cli,cli_text)
importFrom(cli,cli_warn)
importFrom(dplyr,across)
importFrom(dplyr,add_count)
importFrom(dplyr,add_tally)
importFrom(dplyr,any_of)
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,count)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,group_vars)
importFrom(dplyr,grouped_df)
importFrom(dplyr,if_all)
importFrom(dplyr,if_any)
importFrom(dplyr,if_else)
importFrom(dplyr,is_grouped_df)
importFrom(dplyr,join_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,n_distinct)
importFrom(dplyr,pick)
importFrom(dplyr,relocate)
importFrom(dplyr,rename)
importFrom(dplyr,rename_with)
importFrom(dplyr,row_number)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,slice_head)
importFrom(dplyr,slice_max)
importFrom(dplyr,slice_min)
importFrom(dplyr,slice_sample)
importFrom(dplyr,slice_tail)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(dplyr,symdiff)
importFrom(dplyr,tally)
importFrom(dplyr,ungroup)
importFrom(grDevices,colours)
importFrom(haven,as_factor)
importFrom(haven,labelled)
importFrom(methods,is)
importFrom(methods,setOldClass)
importFrom(pillar,pillar_shaft)
importFrom(pillar,tbl_format_footer)
importFrom(pillar,tbl_sum)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(tibble,as_tibble)
importFrom(tibble,is_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,build_wider_spec)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,pivot_wider_spec)
importFrom(tidyselect,all_of)
importFrom(tidyselect,eval_select)
importFrom(tidyselect,everything)
importFrom(tidyselect,starts_with)
importFrom(tidyselect,where)
importFrom(vctrs,vec_cast)
